pub enum SelectError {
ParseError(UnexpectedTokenError),
NoMatchError,
}Expand description
Errors which can be returned when performing a select operation.
Variants
ParseError(UnexpectedTokenError)
Returned when the selector could not be parsed successfully.
NoMatchError
Returned when there were no matches for the selector.